"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HTTPBackend = void 0;
const check_type_1 = require("../utils/check-type");
const json_1 = require("../formatters/json");
/**
 * A backend that reports errors via HTTP.
 *
 * By default, this reporter will use the global `fetch`, but one can be
 * provided when a global one is unavailable.
 *
 * ```ts
 * const backend = new HTTPBackend({
 *   fetchFn: fetchPolyfill,
 *   haystackURL: process.env.HAYSTACK_URL
 * })
 * ```
 */
class HTTPBackend {
    constructor(opts) {
        const { haystackURL, app, headers, fetchFn } = opts;
        (0, check_type_1.checkType)(haystackURL, 'string', 'haystackURL');
        this.haystackURL = haystackURL;
        this.app = app;
        this.headers = headers !== null && headers !== void 0 ? headers : {};
        this.fetchFn = fetchFn;
    }
    report(error, metadata) {
        const body = (0, json_1.formatJSON)(error, Object.assign({ app: this.app }, metadata));
        const headers = this.headers;
        headers['content-type'] = 'application/json';
        return this.fetch(this.haystackURL, {
            method: 'POST',
            body: JSON.stringify(body),
            headers
        });
    }
    get fetch() {
        if (this.fetchFn) {
            return this.fetchFn;
        }
        if (typeof fetch !== 'undefined') {
            return fetch;
        }
        throw new Error('No fetchFn provided and no global "fetch" available');
    }
}
exports.HTTPBackend = HTTPBackend;
//# sourceMappingURL=http.js.map